.. Config Suite documentation master file, created by
   sphinx-quickstart on Thu May 16 13:14:53 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Config Suite
============

*Config Suite* is the result of recognizing the complexity of software configuration.

.. toctree::
    :maxdepth: 2
    :caption: Contents:


The User Guide
--------------

A guide through the universe of *Config Suite*.

.. toctree::
    :maxdepth: 2

    user_guide/introduction
    user_guide/getting_started
    user_guide/advanced
    user_guide/deprecated_behaviour


Additional examples
-------------------

For additional examples we refer the reader to the `test data <https://github.com/equinor/configsuite/tree/master/tests/data>`_.

Release Notes
-------------

An overview of the *Config Suite* releases.

.. toctree::
    :maxdepth: 2

    release_notes


The API Documentation
---------------------

In-deepth documentation of the API of *Config Suite*.

.. toctree::
    :maxdepth: 2

    api
